@@ -36,8 +36,11 @@ class MainWindowWidgetManager(QtWidgets.QMainWindow, Ui_MainWindow):
     def __init__(self, *args, **kwargs):
         super(MainWindowWidgetManager, self).__init__(*args, **kwargs)
         
+        self.dirPath = os.path.dirname(os.path.realpath(__file__))
+        self.imagePath = self.dirPath + "/../../img/"
+        
         self.setWindowTitle('Dassym - Slave Control Panel')
-        iconPath = os.path.dirname(os.path.realpath(__file__)) + '/../../img/dassym-icon.png'
+        iconPath = self.imagePath + 'dassym-icon.png'
         self.setWindowIcon(QIcon(iconPath))
         
         self.proxyHost = ""
@@ -48,8 +51,9 @@ class MainWindowWidgetManager(QtWidgets.QMainWindow, Ui_MainWindow):
         self.consoleText = ""
                 
         # button linker
-        self.buttonConnexion.clicked.connect(self.onButtonConnexionClicked)  
-        self.setConnexionStatus(False)   
+        self.buttonConnexion.clicked.connect(self.onButtonConnexionClicked)
+        self.actionauto_connect.triggered.connect(self.onAutoConnectTriggered)
+        self.setConnexionStatus(False)
            
       
     def onButtonConnexionClicked(self):
@@ -57,6 +61,10 @@ class MainWindowWidgetManager(QtWidgets.QMainWindow, Ui_MainWindow):
         """
         assert False
         pass
+    
+    def onAutoConnectTriggered(self):
+        assert False
+        pass
         
     def putInConsole(self, msg):
         """put a message in console object in log format
@@ -69,13 +77,15 @@ class MainWindowWidgetManager(QtWidgets.QMainWindow, Ui_MainWindow):
         
     def setConnexionStatus(self, connected=True):
         text = None
-        icon = None
+        icon = self.imagePath
+        
         if connected:
-            icon = os.path.dirname(os.path.realpath(__file__)) + "/../../img/dot-green.svg"
+            icon += "dot-green.svg"
             text = 'Connected to proxy @ {}:{}'.format(self.proxyHost, self.proxyPort)
         else:
-            icon = os.path.dirname(os.path.realpath(__file__)) + "/../../img/dot-red.svg"
+            icon += "dot-red.svg"
             text = 'Disconnected from proxy'
+            
         self.proxyStatus.setText(text)
         self.proxyStatusImage.setPixmap(QPixmap(icon).scaled(15, 15))
         
@@ -161,10 +171,10 @@ class MainWindow(MainWindowWidgetManager):
         super().__init__()
         
         
-        dirpath = os.path.dirname(os.path.realpath(__file__))
-        configFile= dirpath + "/../conf.txt"
+        configFile= self.dirPath + "/../conf.txt"
         self.confFile = File(configFile)
         self.selectCom = False
+        self.automaticReconnect = True
         
         self.config = config
         if self.config.host is not None:
@@ -182,7 +192,7 @@ class MainWindow(MainWindowWidgetManager):
         """init all the components for the board and the board itself
         """
 
-        # try to connect to the board
+        # select the port
         if port is None:
             ports = list(list_ports.comports())
             if len(ports) == 1:
@@ -190,26 +200,27 @@ class MainWindow(MainWindowWidgetManager):
             if len(ports) > 1:
                 self.selectSerial(ports)
                 return
-            
+        
+        # raise exception if no port have been choose
         if port is None:
             raise Exception("No serial port detected") 
         
+        # make the communication between the pc and the board
         self.serial = serial.Serial(port[0], timeout=1)
         self.comm = dapi2.DSerial(self.serial)
         self.api = dapi2.DApi2(self.comm)
                 
+        # try to connect to the board
         try:
             self.board = dboard.DBoardFactory(self.api)
         except:
             raise Exception("Cannot connect to the board (connect or power on the board).") from None
         
-
-        
         # extract the board informations
         self.board.getRegisters('system')
         self.board.getRegisters('psvr','wer', refresh=True)
         
-        # create the board strings
+        # create the board informations string
         serialStatus = "SN: {snr:05d}\nDate: {fdr:s}\nHardware: {hvr:s}\nFirmware: {svr:s}\nDate: {fbdr:s}\nBIOS: {bvr:s}\nDate: {bbdr:s}".format(
             snr=self.board.regs.snr.value,
             fdr=wordToDate(self.board.regs.fdr.value).isoformat(),
@@ -219,6 +230,7 @@ class MainWindow(MainWindowWidgetManager):
             bvr=versionToStr(wordToVersion(self.board.regs.bvr.value)),
             bbdr=wordToDate(self.board.regs.bbdr.value).isoformat()
         )
+        self.boardinfos.setText(serialStatus)
         
         # make the status bar of the serial connection to the board
         self.statusBar().showMessage("Connected to {board:s} from {serial:s} @ {speed:s} bauds".format(
@@ -226,8 +238,6 @@ class MainWindow(MainWindowWidgetManager):
                 serial=self.serial.port,
                 speed=str(self.serial.baudrate)
             ))
-        
-        self.boardinfos.setText(serialStatus)
                 
     def selectSerial(self, ports):
         """Launch a dialog for selecting the serial communication port
@@ -247,7 +257,7 @@ class MainWindow(MainWindowWidgetManager):
         :param str msg: message to send to the proxy for initializing connection
         """
          
-            
+        # if the listener cannot connect to proxy, throw an exception
         try:
             self.listener = Listener(self.proxyHost, int(self.proxyPort), msg.encode())
         except Exception:
@@ -278,7 +288,8 @@ class MainWindow(MainWindowWidgetManager):
             self.putInConsole("Initialization of the connection")
             self.startListener(msg)
             
-
+    def onAutoConnectTriggered(self):
+        self.automaticReconnect = not self.automaticReconnect
                 
     def loadConf(self):
         """read the config file and initialize variable
@@ -343,5 +354,7 @@ class MainWindow(MainWindowWidgetManager):
         self.thread.wait()
         self.enableInterface()
         self.setConnexionStatus(False)
+        if self.automaticReconnect:
+            self.onButtonConnexionClicked()
         
         
\ No newline at end of file
