@@ -50,12 +50,14 @@ class Listener(QObject):
         
         self.write(initMsg)
         
-    
     def write(self, data):
         """Write data on the socket
         
         :param bytes data: contain the data to send
         """
+        if not isinstance(data, bytes):
+            data = data.encode()
+            
         self.logSignal.emit("Send " + str(data.decode()))
         self.s.send(data)
 
